FacebookAuthCredential class

The auth credential returned from calling FacebookAuthProvider.credential.

Inheritance

Properties

accessToken → String?
The OAuth access token associated with the credential if it belongs to an OAuth provider, such as facebook.com, twitter.com, etc.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
idToken → String?
The OAuth ID token associated with the credential if it belongs to an OIDC provider, such as google.com.
finalinherited
providerId → String
The authentication provider ID for the credential. For example, 'facebook.com', or 'google.com'.
finalinherited
rawNonce → String?
The raw nonce associated with the ID token. It is required when an ID token with a nonce field is provided. The SHA-256 hash of the raw nonce must match the nonce field in the ID token.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secret → String?
The OAuth access token secret associated with the credential if it belongs to an OAuth 1.0 provider, such as twitter.com.
finalinherited
signInMethod → String
The authentication sign in method for the credential. For example, 'password', or 'emailLink'. This corresponds to the sign-in method identifier returned in fetchSignInMethodsForEmail.
finalinherited
token → int?
A token used to identify the AuthCredential on native platforms.
finalinherited

Methods

asMap() → Map<String, String?>
Returns the current instance as a serialized Map.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited